diff --git a/demos/main/src/main/AndroidManifest.xml b/demos/main/src/main/AndroidManifest.xml
index 1f66822dc7..4f90cef623 100644
--- a/demos/main/src/main/AndroidManifest.xml
+++ b/demos/main/src/main/AndroidManifest.xml
@@ -23,7 +23,7 @@
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
= 11) {
- setViewAlphaV11(view, enabled ? 1f : 0.3f);
- view.setVisibility(VISIBLE);
- } else {
- view.setVisibility(enabled ? VISIBLE : INVISIBLE);
- }
- }
-
- @TargetApi(11)
- private void setViewAlphaV11(View view, float alpha) {
- view.setAlpha(alpha);
+ view.setAlpha(enabled ? 1f : 0.3f);
+ view.setVisibility(VISIBLE);
}
private void previous() {
diff --git a/playbacktests/src/androidTest/AndroidManifest.xml b/playbacktests/src/androidTest/AndroidManifest.xml
index 053fe4e61c..1a660591d8 100644
--- a/playbacktests/src/androidTest/AndroidManifest.xml
+++ b/playbacktests/src/androidTest/AndroidManifest.xml
@@ -21,7 +21,7 @@
-
+
diff --git a/constants.gradle b/constants.gradle
index b7cc8b6906..576091f937 100644
--- a/constants.gradle
+++ b/constants.gradle
@@ -12,16 +12,16 @@
// See the License for the specific language governing permissions and
// limitations under the License.
project.ext {
// Important: ExoPlayer specifies a minSdkVersion of 9 because various
// components provided by the library may be of use on older devices.
// However, please note that the core media playback functionality provided
// by the library requires API level 16 or greater.
- minSdkVersion = 9
- compileSdkVersion = 25
- targetSdkVersion = 25
- buildToolsVersion = '25'
+ minSdkVersion = 14
+ compileSdkVersion = 26
+ targetSdkVersion = 26
+ buildToolsVersion = '26'
testSupportLibraryVersion = '0.5'
- supportLibraryVersion = '25.4.0'
+ supportLibraryVersion = '26.0.1'
dexmakerVersion = '1.2'
mockitoVersion = '1.9.5'
releaseVersion = 'r2.5.1'
@@ -12,16 +12,16 @@
// limitations under the License.
project.ext {
- // Important: ExoPlayer specifies a minSdkVersion of 9 because various
+ // Important: ExoPlayer specifies a minSdkVersion of 14 because various
// components provided by the library may be of use on older devices.
// However, please note that the core media playback functionality provided